@@ -18,11 +18,12 @@ import builtins
 from collections import namedtuple
 import copy
 from dataclasses import Field, InitVar, MISSING, dataclass, field, fields, replace
-from dataclasses_json import config, global_config
+from dataclasses_json import global_config
 from dataclasses_json.core import _is_supported_generic, _decode_generic
+import dataclasses_json.core
 import datetime as dt
 from enum import EnumMeta
-import inflection
+from inflection import camelize, underscore
 import inspect
 import keyword
 import logging
@@ -40,7 +41,6 @@ __builtins = set(dir(builtins))
 __iskeyword = keyword.iskeyword
 __getattribute__ = object.__getattribute__
 __setattr__ = object.__setattr__
-_underscore = inflection.underscore
 
 
 def is_iterable(o, t):
@@ -80,7 +80,13 @@ class EnumBase:
         return self.value
 
 
-class DictBase(dict):
+class HashableDict(dict):
+
+    def __hash__(self):
+        return hash(tuple(self.items()))
+
+
+class DictBase(HashableDict):
 
     _PROPERTIES = set()
 
@@ -90,11 +96,17 @@ class DictBase(dict):
             if invalid_arg is not None:
                 raise AttributeError(f"'{self.__class__.__name__}' has no attribute '{invalid_arg}'")
 
-        super().__init__(*args, **kwargs)
+        super().__init__(*args, **{camelize(k, uppercase_first_letter=False): v for k, v in kwargs.items()})
+
+    def __getitem__(self, item):
+        return super().__getitem__(camelize(item, uppercase_first_letter=False))
+
+    def __setitem__(self, key, value):
+        return super().__setitem__(camelize(key, uppercase_first_letter=False), value)
 
     def __getattr__(self, item):
         if self._PROPERTIES:
-            if item in self._PROPERTIES:
+            if underscore(item) in self._PROPERTIES:
                 return self.get(item)
         elif item in self:
             return self[item]
@@ -104,14 +116,11 @@ class DictBase(dict):
     def __setattr__(self, key, value):
         if key in dir(self):
             return super().__setattr__(key, value)
-        elif self._PROPERTIES and key not in self._PROPERTIES:
+        elif self._PROPERTIES and underscore(key) not in self._PROPERTIES:
             raise AttributeError(f"'{self.__class__.__name__}' has no attribute '{key}'")
 
         self[key] = value
 
-    def __hash__(self):
-        return hash(tuple(self.items()))
-
     @classmethod
     def properties(cls) -> set:
         return cls._PROPERTIES
@@ -143,7 +152,7 @@ def fix_args(cls):
 
         for arg, value in kwargs.items():
             if not arg.isupper():
-                snake_case_arg = _underscore(arg)
+                snake_case_arg = underscore(arg)
                 if snake_case_arg != arg and snake_case_arg in kwargs:
                     raise ValueError('{} and {} both specified'.format(arg, snake_case_arg))
 
@@ -164,8 +173,6 @@ def fix_args(cls):
 
     if add_name:
         cls.__doc__ = cls.__doc__[:-1] + f', name: Union[str, NoneType] = None)'
-        annotations = copy.copy(init.__annotations__)
-        annotations['name'] = Optional[str]
         wrapper.__annotations__ = {**{'name': Optional[str]}, **init.__annotations__}
 
     wrapper.__signature__ = signature
@@ -196,7 +203,7 @@ class Base(ABC):
             return __getattribute__(self, 'name_')
 
         # Handle setting via camelCase names (legacy behaviour) and field mappings from disallowed names
-        snake_case_item = _underscore(item)
+        snake_case_item = underscore(item)
         field_mappings = __getattribute__(self, '_field_mappings')()
         snake_case_item = field_mappings.get(snake_case_item, snake_case_item)
 
@@ -207,7 +214,7 @@ class Base(ABC):
 
     def __setattr__(self, key, value):
         # Handle setting via camelCase names (legacy behaviour)
-        snake_case_key = inflection.underscore(key)
+        snake_case_key = underscore(key)
         snake_case_key = self._field_mappings().get(snake_case_key, snake_case_key)
         fld = self._fields_by_name().get(snake_case_key)
 
@@ -316,7 +323,7 @@ class Base(ABC):
 
             if value is not None:
                 if as_camel_case:
-                    key = inflection.camelize(key, uppercase_first_letter=False)
+                    key = camelize(key, uppercase_first_letter=False)
 
                 ret[key] = value
 
@@ -538,11 +545,6 @@ class InstrumentBase(Base):
             self.__unresolved = None
 
 
-class QuotableBuilder(Base):
-
-    valuation_overrides: dict = field(default={}, metadata=config(field_name='overrides'))
-
-
 @dataclass
 class Market(ABC):
 
@@ -621,3 +623,18 @@ global_config.decoders[Optional[InstrumentBase]] = decode_instrument
 
 global_config.encoders[Market] = encode_dictable
 global_config.encoders[Optional[Market]] = encode_dictable
+
+
+def __decode_dataclass(cls, kvs, infer_missing):
+    # EXTREMELY unfortunate
+    if isinstance(kvs, cls):
+        return kvs
+    elif hasattr(cls, 'decode_dataclass'):
+        return cls.decode_dataclass(kvs)
+    else:
+        from dataclasses_json.core import _decode_dataclass_orig
+        return _decode_dataclass_orig(cls, kvs, infer_missing)
+
+
+dataclasses_json.core._decode_dataclass_orig = dataclasses_json.core._decode_dataclass
+dataclasses_json.core._decode_dataclass = __decode_dataclass
