@@ -16,8 +16,8 @@ under the License.
 
 import datetime as dt
 import logging
-import numpy as np
 
+import numpy as np
 from gs_quant.errors import *
 
 _logger = logging.getLogger(__name__)
@@ -58,6 +58,50 @@ class Timer:
                     f'{self.__label} took {self.__elapsed.seconds + self.__elapsed.microseconds / 1000000} seconds')
 
 
+class Tracer:
+    __stack_depth = 0
+    __stack = []
+
+    def __init__(self, label: str = 'Execution', print_on_exit: bool = False, threshold: int = None):
+        self.__print_on_exit = print_on_exit
+        self.__label = label
+        self.__threshold = threshold
+
+    def __enter__(self):
+        self.__start = dt.datetime.now()
+        self.__index = len(Tracer.__stack)
+        Tracer.__stack.append([dt.datetime.now(), 0.0, self.__label, Tracer.__stack_depth])
+        Tracer.__stack_depth += 1
+
+    def __exit__(self, *args):
+        self.__elapsed = dt.datetime.now() - self.__start
+        elapsed_sec = self.__elapsed.seconds + self.__elapsed.microseconds / 1000000
+        Tracer.__stack[self.__index][1] = elapsed_sec
+        Tracer.__stack_depth -= 1
+        if self.__print_on_exit:
+            if self.__threshold is None or self.__elapsed.seconds > self.__threshold:
+                _logger.warning(f'{self.__label} took {elapsed_sec} seconds')
+
+    @staticmethod
+    def reset():
+        Tracer.__stack_depth = 0
+        Tracer.__stack = []
+
+    @staticmethod
+    def print(reset=True):
+        lines = []
+        total = 0
+        for span in Tracer.__stack:
+            name = f'{"* " * span[3]}{span[2]}'
+            lines.append(f'{name:<50}{span[1] * 1000:>8.1f} ms')
+            if span[3] == 0:
+                total += span[1] * 1000
+        tracing_str = '\n'.join(lines)
+        _logger.warning(f'Tracing Info:\n{tracing_str}\n{"-" * 61}\nTOTAL:{total:>52.1f} ms')
+        if reset:
+            Tracer.reset()
+
+
 def to_zulu_string(time: dt.datetime):
     return time.isoformat()[:-3] + 'Z'
 
