@@ -187,12 +187,15 @@ def test_asset_types(mocker):
     ata = getattr(SecurityMaster, '_SecurityMaster__gs_asset_to_asset')
     assert ata is not None
     asset = GsAsset(AssetClass.Equity, None, 'Test Asset')
-    setattr(asset, '_Asset__type', MockType.Foo)
 
     mocker.patch.object(json, 'dumps', return_value='{}')
-    with pytest.raises(TypeError) as exc_info:
+    # with pytest.raises(ValueError) as exc_info:
+    #     setattr(asset, 'type', MockType.Foo)
+    # assert 'is not a valid AssetType' in str(exc_info.value)  # reached exception at end of function
+
+    with pytest.raises(AttributeError) as exc_info:
         ata(asset)
-    assert 'unsupported asset type' in str(exc_info.value)  # reached exception at end of function
+    assert "has no attribute 'value'" in str(exc_info.value)  # reached exception at end of function
 
 
 class SecMasterContext:
@@ -906,6 +909,14 @@ def test_map_identifiers_asset_service(mocker):
                                                 as_of_date=datetime.date(2021, 10, 11))
     assert actual == expected
 
+    date_string = datetime.date.today().strftime('%Y-%m-%d')
+    expected2 = {date_string: expected["2021-10-11"]}
+    with AssetContext():
+        actual2 = SecurityMaster.map_identifiers(SecurityIdentifier.BBID,
+                                                 ['GS UN', 'AAPL UN'],
+                                                 [SecurityIdentifier.RIC])
+    assert actual2 == expected2
+
     mocker.patch.object(GsAssetApi, 'map_identifiers', side_effect=lambda *arg, **kwargs: {})
     with AssetContext():
         actual = SecurityMaster.map_identifiers(SecurityIdentifier.BBID,
