@@ -449,7 +449,7 @@ def day_count_fractions(
         date_list = dates
 
     if len(date_list) < 2:
-        return pd.Series([])
+        return pd.Series(dtype=float)
 
     start_dates = date_list[0:-1]
     end_dates = date_list[1:len(date_list)]
@@ -483,6 +483,10 @@ def date_range(x: pd.Series, start_date: Union[date, int], end_date: Union[date,
     >>> series = generate_series(100)
     >>> sliced_series = date_range(series,7,7)
 
+    create time series with the absolute date:
+
+    >>> date_range(series, Date(2021,1,1), Date(2021,12,30))
+
     **See also**
 
     :func:`day` :func: `lag`
